Module request

Module request 

Structs

Request
Wrapper type for CoAP requests carrying extra context from filtering. This API is not considered stable and in particular the inclusion of the CoapRequest reference is likely to be removed in future versions when matching/filtering is more robust.