FramedReadError

Type Alias FramedReadError 

pub type FramedReadError<Endpoint> = (TransportError, Option<Endpoint>);
Error when receiving from a remote peer. Note that here [Endpoint] is optional as there may be a generic read error unrelated to any remote peer, for example if the underlying bound socket is closed.