FramedWriteError

Type Alias FramedWriteError 

pub type FramedWriteError = TransportError;
Error when sending to a remote peer. Note that [Endpoint] is omitted in this case as the endpoint is provided to the send APIs themselves so we can easily tell which peer generated the error.

Aliased Type

pub enum FramedWriteError {
    IoError(Option<Error>),
    MalformedPacket(MessageError),
    Unspecified(String),
}

Variants



IoError(Option<Error>)



MalformedPacket(MessageError)



Unspecified(String)